Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(90)

Unified Diff: content/common/speech_recognition_messages.h

Issue 9568002: Renamed speech input implementation from to speech_recognition_*. The namespace has been renamed fr… (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Rebased from master. Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/speech_input_messages.h ('k') | content/content_browser.gypi » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/common/speech_recognition_messages.h
diff --git a/content/common/speech_input_messages.h b/content/common/speech_recognition_messages.h
similarity index 50%
rename from content/common/speech_input_messages.h
rename to content/common/speech_recognition_messages.h
index f50e05723d4a02fda73a8c8b2dd1833b1c19a9f5..7ab76c1c445a590201571e74336877370eb6cbca 100644
--- a/content/common/speech_input_messages.h
+++ b/content/common/speech_recognition_messages.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -6,27 +6,27 @@
#include <string>
-#include "content/public/common/speech_input_result.h"
+#include "content/public/common/speech_recognition_result.h"
#include "ipc/ipc_message_macros.h"
#include "ipc/ipc_param_traits.h"
#include "ui/gfx/rect.h"
-#define IPC_MESSAGE_START SpeechInputMsgStart
+#define IPC_MESSAGE_START SpeechRecognitionMsgStart
-IPC_ENUM_TRAITS(content::SpeechInputError)
+IPC_ENUM_TRAITS(content::SpeechRecognitionErrorCode)
-IPC_STRUCT_TRAITS_BEGIN(content::SpeechInputHypothesis)
+IPC_STRUCT_TRAITS_BEGIN(content::SpeechRecognitionHypothesis)
IPC_STRUCT_TRAITS_MEMBER(utterance)
IPC_STRUCT_TRAITS_MEMBER(confidence)
IPC_STRUCT_TRAITS_END()
-IPC_STRUCT_TRAITS_BEGIN(content::SpeechInputResult)
+IPC_STRUCT_TRAITS_BEGIN(content::SpeechRecognitionResult)
IPC_STRUCT_TRAITS_MEMBER(error)
IPC_STRUCT_TRAITS_MEMBER(hypotheses)
IPC_STRUCT_TRAITS_END()
// Used to start a speech recognition session.
-IPC_STRUCT_BEGIN(SpeechInputHostMsg_StartRecognition_Params)
+IPC_STRUCT_BEGIN(InputTagSpeechHostMsg_StartRecognition_Params)
// The render view requesting speech recognition.
IPC_STRUCT_MEMBER(int, render_view_id)
// Request ID used within the render view.
@@ -35,53 +35,52 @@ IPC_STRUCT_BEGIN(SpeechInputHostMsg_StartRecognition_Params)
IPC_STRUCT_MEMBER(gfx::Rect, element_rect)
// Language to use for speech recognition.
IPC_STRUCT_MEMBER(std::string, language)
- // Speech grammar given by the speech input element.
+ // Speech grammar given by the speech recognition element.
IPC_STRUCT_MEMBER(std::string, grammar)
// URL of the page (or iframe if applicable).
IPC_STRUCT_MEMBER(std::string, origin_url)
IPC_STRUCT_END()
-// Speech input messages sent from the renderer to the browser.
+// Speech recognition messages sent from the renderer to the browser.
-// Requests the speech input service to start speech recognition on behalf of
-// the given |render_view_id|.
-IPC_MESSAGE_CONTROL1(SpeechInputHostMsg_StartRecognition,
- SpeechInputHostMsg_StartRecognition_Params)
+// Requests the speech recognition service to start speech recognition on behalf
+// of the given |render_view_id|.
+IPC_MESSAGE_CONTROL1(InputTagSpeechHostMsg_StartRecognition,
+ InputTagSpeechHostMsg_StartRecognition_Params)
-// Requests the speech input service to cancel speech recognition on behalf of
-// the given |render_view_id|. If speech recognition is not happening or
-// is happening on behalf of some other render view, this call does nothing.
-IPC_MESSAGE_CONTROL2(SpeechInputHostMsg_CancelRecognition,
+// Requests the speech recognition service to cancel speech recognition on
+// behalf of the given |render_view_id|. If speech recognition is not happening
+// or is happening on behalf of some other render view, this call does nothing.
+IPC_MESSAGE_CONTROL2(InputTagSpeechHostMsg_CancelRecognition,
int /* render_view_id */,
int /* request_id */)
-// Requests the speech input service to stop audio recording on behalf of
+// Requests the speech recognition service to stop audio recording on behalf of
// the given |render_view_id|. Any audio recorded so far will be fed to the
// speech recognizer. If speech recognition is not happening nor or is
// happening on behalf of some other render view, this call does nothing.
-IPC_MESSAGE_CONTROL2(SpeechInputHostMsg_StopRecording,
+IPC_MESSAGE_CONTROL2(InputTagSpeechHostMsg_StopRecording,
int /* render_view_id */,
int /* request_id */)
-// Speech input messages sent from the browser to the renderer.
+// Speech recognition messages sent from the browser to the renderer.
// Relay a speech recognition result, either partial or final.
-IPC_MESSAGE_ROUTED2(SpeechInputMsg_SetRecognitionResult,
+IPC_MESSAGE_ROUTED2(InputTagSpeechMsg_SetRecognitionResult,
int /* request_id */,
- content::SpeechInputResult /* result */)
+ content::SpeechRecognitionResult /* result */)
// Indicate that speech recognizer has stopped recording and started
// recognition.
-IPC_MESSAGE_ROUTED1(SpeechInputMsg_RecordingComplete,
+IPC_MESSAGE_ROUTED1(InputTagSpeechMsg_RecordingComplete,
int /* request_id */)
-// Indicate that speech recognizer has completed recognition. This will be
-// the last message sent in response to a
-// ViewHostMsg_SpeechInput_StartRecognition.
-IPC_MESSAGE_ROUTED1(SpeechInputMsg_RecognitionComplete,
+// Indicate that speech recognizer has completed recognition. This will be the
+// last message sent in response to a InputTagSpeechHostMsg_StartRecognition.
+IPC_MESSAGE_ROUTED1(InputTagSpeechMsg_RecognitionComplete,
int /* request_id */)
-// Toggle speech input on or off on the speech input control for the
+// Toggle speech recognition on or off on the speech input control for the
// current focused element. Has no effect if the current element doesn't
-// support speech input.
-IPC_MESSAGE_ROUTED0(SpeechInputMsg_ToggleSpeechInput)
+// support speech recognition.
+IPC_MESSAGE_ROUTED0(InputTagSpeechMsg_ToggleSpeechInput)
« no previous file with comments | « content/common/speech_input_messages.h ('k') | content/content_browser.gypi » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698